==> brevia-0.0.16-py3-none-any.whl: brevia/alembic/env.py <==
from logging.config import fileConfig
from sqlalchemy import engine_from_config
from sqlalchemy import pool
from alembic import context
from sqlalchemy_utils import database_exists, create_database
from brevia.connection import connection_string

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# we need to double escape "%" into "%%"
# because alembic uses configparser (that requires an additional escape of %)
# see https://github.com/sqlalchemy/alembic/issues/700
db_url = connection_string()
config.set_section_option('alembic', 'sqlalchemy.url', db_url.replace('%', '%%'))

# Try to create database if it does not exist.
if not database_exists(db_url):
    config.print_stdout(f'Database does not exist: {db_url}')
    config.print_stdout('Trying to create one')
    create_database(db_url)

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import mymodel
# target_metadata = mymodel.Base.metadata
target_metadata = None

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section, {}),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata,
            compare_type=True,
            compare_server_default=True,
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> brevia-0.14.0-py3-none-any.whl: brevia/alembic/env.py <==
from logging.config import fileConfig
from sqlalchemy import engine_from_config
from sqlalchemy import pool
from alembic import context
from sqlalchemy_utils import database_exists, create_database
from brevia.connection import connection_string
# Import models for autogenerate support
from brevia.chat_history import ChatHistoryStore  # noqa: F401
from brevia.async_jobs import AsyncJobsStore  # noqa: F401
from brevia.settings import ConfigStore  # noqa: F401
from langchain_community.vectorstores.pgembedding import (  # noqa: F401
    BaseModel,
    CollectionStore,
    EmbeddingStore,
)

# this is the Alembic Config object, which provides
# access to the values within the .ini file in use.
config = context.config

# we need to double escape "%" into "%%"
# because alembic uses configparser (that requires an additional escape of %)
# see https://github.com/sqlalchemy/alembic/issues/700
db_url = connection_string()
config.set_section_option('alembic', 'sqlalchemy.url', db_url.replace('%', '%%'))

# Try to create database if it does not exist.
if not database_exists(db_url):
    config.print_stdout(f'Database does not exist: {db_url}')
    config.print_stdout('Trying to create one')
    create_database(db_url)

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# Models are imported at the top of the file
target_metadata = BaseModel.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired:
# my_important_option = config.get_main_option("my_important_option")
# ... etc.


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section, {}),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata,
            compare_type=True,
            compare_server_default=True,
        )

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
